@@ -1,12 +1,9 @@
 use crate::line_editor::configure_ctrl_c;
 use nu_command::commands::default_context::create_default_context;
-#[allow(unused_imports)]
-use nu_command::maybe_print_errors;
-use nu_engine::run_block;
-use nu_engine::EvaluationContext;
+use nu_engine::{evaluation_context, run_block, script::run_script_standalone, EvaluationContext};
 
 #[allow(unused_imports)]
-pub(crate) use nu_command::script::{process_script, LineResult};
+pub(crate) use nu_engine::script::{process_script, LineResult};
 
 #[cfg(feature = "rustyline-support")]
 use crate::line_editor::{
@@ -16,13 +13,13 @@ use crate::line_editor::{
 
 #[allow(unused_imports)]
 use nu_data::config;
-use nu_source::{Tag, Text};
+use nu_data::config::{Conf, NuConfig};
+use nu_source::{AnchorLocation, Tag, Text};
 use nu_stream::InputStream;
+use std::ffi::{OsStr, OsString};
 #[allow(unused_imports)]
 use std::sync::atomic::Ordering;
 
-use nu_command::script::{print_err, run_script_standalone};
-
 #[cfg(feature = "rustyline-support")]
 use rustyline::{self, error::ReadlineError};
 
@@ -36,6 +33,81 @@ use std::error::Error;
 use std::iter::Iterator;
 use std::path::PathBuf;
 
+pub struct Options {
+    pub config: Option<OsString>,
+    pub history: Option<PathBuf>,
+    pub save_history: bool,
+    pub stdin: bool,
+    pub scripts: Vec<NuScript>,
+}
+
+impl Default for Options {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
+impl Options {
+    pub fn new() -> Self {
+        Self {
+            config: None,
+            history: None,
+            save_history: true,
+            stdin: false,
+            scripts: vec![],
+        }
+    }
+
+    pub fn history(&self, block: impl FnOnce(&std::path::Path)) {
+        if !self.save_history {
+            return;
+        }
+
+        if let Some(file) = &self.history {
+            block(&file)
+        }
+    }
+}
+
+pub struct NuScript {
+    pub filepath: Option<OsString>,
+    pub contents: String,
+}
+
+impl NuScript {
+    pub fn code<'a>(content: impl Iterator<Item = &'a str>) -> Result<Self, ShellError> {
+        let text = content
+            .map(|x| x.to_string())
+            .collect::<Vec<String>>()
+            .join("\n");
+
+        Ok(Self {
+            filepath: None,
+            contents: text,
+        })
+    }
+
+    pub fn get_code(&self) -> &str {
+        &self.contents
+    }
+
+    pub fn source_file(path: &OsStr) -> Result<Self, ShellError> {
+        use std::fs::File;
+        use std::io::Read;
+
+        let path = path.to_os_string();
+        let mut file = File::open(&path)?;
+        let mut buffer = String::new();
+
+        file.read_to_string(&mut buffer)?;
+
+        Ok(Self {
+            filepath: Some(path),
+            contents: buffer,
+        })
+    }
+}
+
 pub fn search_paths() -> Vec<std::path::PathBuf> {
     use std::env;
 
@@ -65,12 +137,9 @@ pub fn search_paths() -> Vec<std::path::PathBuf> {
     search_paths
 }
 
-pub async fn run_script_file(
-    file_contents: String,
-    redirect_stdin: bool,
-) -> Result<(), Box<dyn Error>> {
-    let mut syncer = EnvironmentSyncer::new();
+pub async fn run_script_file(mut options: Options) -> Result<(), Box<dyn Error>> {
     let mut context = create_default_context(false)?;
+    let mut syncer = create_environment_syncer(&context, &mut options);
     let config = syncer.get_config();
 
     context.configure(&config, |_, ctx| {
@@ -79,7 +148,7 @@ pub async fn run_script_file(
         syncer.sync_path_vars(ctx);
 
         if let Err(reason) = syncer.autoenv(ctx) {
-            print_err(reason, &Text::from(""), ctx);
+            ctx.with_host(|host| host.print_err(reason, &Text::from("")));
         }
 
         let _ = register_plugins(ctx);
@@ -88,15 +157,62 @@ pub async fn run_script_file(
 
     let _ = run_startup_commands(&mut context, &config).await;
 
-    run_script_standalone(file_contents, redirect_stdin, &context, true).await?;
+    let script = options
+        .scripts
+        .get(0)
+        .ok_or_else(|| ShellError::unexpected("Nu source code not available"))?;
+
+    run_script_standalone(script.get_code().to_string(), options.stdin, &context, true).await?;
 
     Ok(())
 }
 
-/// The entry point for the CLI. Will register all known internal commands, load experimental commands, load plugins, then prepare the prompt and line reader for input.
+fn create_environment_syncer(
+    context: &EvaluationContext,
+    options: &mut Options,
+) -> EnvironmentSyncer {
+    let configuration = match &options.config {
+        Some(config_file) => {
+            let location = Some(AnchorLocation::File(
+                config_file.to_string_lossy().to_string(),
+            ));
+
+            let tag = Tag::unknown().anchored(location);
+
+            context.scope.add_var(
+                "config-path",
+                UntaggedValue::filepath(PathBuf::from(&config_file)).into_value(tag),
+            );
+
+            NuConfig::with(Some(config_file.into()))
+        }
+        None => NuConfig::new(),
+    };
+
+    let history_path = configuration.history_path();
+    options.history = Some(history_path.clone());
+
+    let location = Some(AnchorLocation::File(
+        history_path.to_string_lossy().to_string(),
+    ));
+
+    let tag = Tag::unknown().anchored(location);
+
+    context.scope.add_var(
+        "history-path",
+        UntaggedValue::filepath(history_path).into_value(tag),
+    );
+
+    EnvironmentSyncer::with_config(Box::new(configuration))
+}
+
 #[cfg(feature = "rustyline-support")]
-pub async fn cli(mut context: EvaluationContext) -> Result<(), Box<dyn Error>> {
-    let mut syncer = EnvironmentSyncer::new();
+pub async fn cli(
+    mut context: EvaluationContext,
+    mut options: Options,
+) -> Result<(), Box<dyn Error>> {
+    let mut syncer = create_environment_syncer(&context, &mut options);
+
     let configuration = syncer.get_config();
 
     let mut rl = default_rustyline_editor_configuration();
@@ -107,7 +223,7 @@ pub async fn cli(mut context: EvaluationContext) -> Result<(), Box<dyn Error>> {
         syncer.sync_path_vars(ctx);
 
         if let Err(reason) = syncer.autoenv(ctx) {
-            print_err(reason, &Text::from(""), ctx);
+            ctx.with_host(|host| host.print_err(reason, &Text::from("")));
         }
 
         let _ = configure_ctrl_c(ctx);
@@ -134,8 +250,9 @@ pub async fn cli(mut context: EvaluationContext) -> Result<(), Box<dyn Error>> {
     // Give ourselves a scope to work in
     context.scope.enter_scope();
 
-    let history_path = nu_engine::history_path(&configuration);
-    let _ = rl.load_history(&history_path);
+    options.history(|file| {
+        let _ = rl.load_history(&file);
+    });
 
     let mut session_text = String::new();
     let mut line_start: usize = 0;
@@ -171,6 +288,7 @@ pub async fn cli(mut context: EvaluationContext) -> Result<(), Box<dyn Error>> {
                 let prompt_line = prompt.as_string()?;
 
                 context.scope.enter_scope();
+
                 let (mut prompt_block, err) = nu_parser::parse(&prompt_line, 0, &context.scope);
 
                 prompt_block.set_redirect(ExternalRedirection::Stdout);
@@ -180,8 +298,6 @@ pub async fn cli(mut context: EvaluationContext) -> Result<(), Box<dyn Error>> {
 
                     format!("\x1b[32m{}{}\x1b[m> ", cwd, current_branch())
                 } else {
-                    // let env = context.get_env();
-
                     let run_result = run_block(&prompt_block, &context, InputStream::empty()).await;
                     context.scope.exit_scope();
 
@@ -189,7 +305,10 @@ pub async fn cli(mut context: EvaluationContext) -> Result<(), Box<dyn Error>> {
                         Ok(result) => match result.collect_string(Tag::unknown()).await {
                             Ok(string_result) => {
                                 let errors = context.get_errors();
-                                maybe_print_errors(&context, Text::from(prompt_line));
+                                evaluation_context::maybe_print_errors(
+                                    &context,
+                                    Text::from(prompt_line),
+                                );
                                 context.clear_errors();
 
                                 if !errors.is_empty() {
@@ -199,14 +318,14 @@ pub async fn cli(mut context: EvaluationContext) -> Result<(), Box<dyn Error>> {
                                 }
                             }
                             Err(e) => {
-                                crate::cli::print_err(e, &Text::from(prompt_line), &context);
+                                context.host.lock().print_err(e, &Text::from(prompt_line));
                                 context.clear_errors();
 
                                 "> ".to_string()
                             }
                         },
                         Err(e) => {
-                            crate::cli::print_err(e, &Text::from(prompt_line), &context);
+                            context.host.lock().print_err(e, &Text::from(prompt_line));
                             context.clear_errors();
 
                             "> ".to_string()
@@ -274,7 +393,7 @@ pub async fn cli(mut context: EvaluationContext) -> Result<(), Box<dyn Error>> {
             }
 
             if let Err(reason) = syncer.autoenv(ctx) {
-                print_err(reason, &Text::from(""), ctx);
+                ctx.with_host(|host| host.print_err(reason, &Text::from("")));
             }
 
             let _ = configure_rustyline_editor(&mut rl, config);
@@ -282,28 +401,33 @@ pub async fn cli(mut context: EvaluationContext) -> Result<(), Box<dyn Error>> {
 
         match line {
             LineResult::Success(line) => {
-                rl.add_history_entry(&line);
-                let _ = rl.save_history(&history_path);
-                maybe_print_errors(&context, Text::from(session_text.clone()));
+                options.history(|file| {
+                    rl.add_history_entry(&line);
+                    let _ = rl.save_history(&file);
+                });
+
+                evaluation_context::maybe_print_errors(&context, Text::from(session_text.clone()));
             }
 
             LineResult::ClearHistory => {
-                rl.clear_history();
-                let _ = rl.save_history(&history_path);
+                options.history(|file| {
+                    rl.clear_history();
+                    let _ = rl.save_history(&file);
+                });
             }
 
-            LineResult::Error(line, err) => {
-                rl.add_history_entry(&line);
-                let _ = rl.save_history(&history_path);
+            LineResult::Error(line, reason) => {
+                options.history(|file| {
+                    rl.add_history_entry(&line);
+                    let _ = rl.save_history(&file);
+                });
 
-                print_err(err, &Text::from(session_text.clone()), &context);
-
-                maybe_print_errors(&context, Text::from(session_text.clone()));
+                context.with_host(|host| host.print_err(reason, &Text::from(session_text.clone())));
             }
 
             LineResult::CtrlC => {
-                let config_ctrlc_exit = config::config(Tag::unknown())?
-                    .get("ctrlc_exit")
+                let config_ctrlc_exit = configuration
+                    .var("ctrlc_exit")
                     .map(|s| s.value.is_true())
                     .unwrap_or(false); // default behavior is to allow CTRL-C spamming similar to other shells
 
@@ -312,7 +436,10 @@ pub async fn cli(mut context: EvaluationContext) -> Result<(), Box<dyn Error>> {
                 }
 
                 if ctrlcbreak {
-                    let _ = rl.save_history(&history_path);
+                    options.history(|file| {
+                        let _ = rl.save_history(&file);
+                    });
+
                     std::process::exit(0);
                 } else {
                     context.with_host(|host| host.stdout("CTRL-C pressed (again to quit)"));
@@ -336,7 +463,9 @@ pub async fn cli(mut context: EvaluationContext) -> Result<(), Box<dyn Error>> {
     }
 
     // we are ok if we can not save history
-    let _ = rl.save_history(&history_path);
+    options.history(|file| {
+        let _ = rl.save_history(&file);
+    });
 
     Ok(())
 }
@@ -426,14 +555,14 @@ fn current_branch() -> String {
 
 #[cfg(test)]
 mod tests {
-    use nu_engine::basic_evaluation_context;
+    use nu_engine::EvaluationContext;
 
     #[quickcheck]
     fn quickcheck_parse(data: String) -> bool {
         let (tokens, err) = nu_parser::lex(&data, 0);
         let (lite_block, err2) = nu_parser::parse_block(tokens);
         if err.is_none() && err2.is_none() {
-            let context = basic_evaluation_context().unwrap();
+            let context = EvaluationContext::basic().unwrap();
             let _ = nu_parser::classify_block(&lite_block, &context.scope);
         }
         true
